<?php

class Sql {
	
	//---------------------------------------------------------
	//  累計カウントテーブルを作成（access_main.db）
	//---------------------------------------------------------
	
	public static function createTotalTable($table) {
		
		// クエリーを作成
		$sql = <<<_SQL_
create table if not exists $table(
	td_date   date unique not null,
	yd_date   date unique not null,
	total_uu  int  unique default 0,
	total_pv  int  unique default 0
);
_SQL_;
		
		// SQLを返す
		return $sql;
		
	}
	
	//---------------------------------------------------------
	//  ページ情報テーブルを作成（access_main.db）
	//---------------------------------------------------------
	
	public static function createPageTable($table) {
		
		// クエリーを作成
		$sql = <<<_SQL_
create table if not exists $table(
	id    int           primary key,
	url   varchar (200) unique not null,
	title varchar (200)
);
_SQL_;
		
		// SQLを返す
		return $sql;
		
	}
	
	//---------------------------------------------------------
	//  訪問者テーブルを作成（access_yyyy_mm.db）
	//---------------------------------------------------------
	
	public static function createVisitTable($table) {
		
		// クエリーを作成
		$sql = <<<_SQL_
create table if not exists $table(
	seq          integer       primary key,
	date         date          not null,
	wday         char (3)      not null,
	last_time    time          not null,
	first_time   time          not null,
	visit_count  int           not null,
	visitor_id   varchar (20),
	ip_address   varchar (40)  not null,
	remote_host  varchar (60)  not null,
	host_domain  varchar (40)  not null,
	referrer     int,
	route        varchar (200) not null,
	stay_time    varchar (300),
	click_route  varchar (200),
	search_words varchar (100),
	ua_type      varchar (10),
	ua_full      varchar (300),
	ua           varchar (80),
	os           varchar (40),
	display_size varchar (20),
	client_size  varchar (20),
	device       varchar (20),
	carrier      varchar (10),
	city         varchar (10)
);
_SQL_;
		
		// SQLを返す
		return $sql;
		
	}
	
	//---------------------------------------------------------
	//  月間パラメータテーブルを作成（access_yyyy_mm.db）
	//---------------------------------------------------------
	
	public static function createParamTable($table) {
		
		// クエリーを作成
		$sql = <<<_SQL_
create table if not exists $table(
	type  varchar (20)  not null,
	value varchar (200) not null,
	count int           not null,
	primary key (type, value)
);
_SQL_;
		
		// SQLを返す
		return $sql;
		
	}
	
	//---------------------------------------------------------
	//  日間パラメータテーブルを作成（access_yyyy_mm.db）
	//---------------------------------------------------------
	
	public static function createDailyTable($table) {
		
		// クエリーを作成
		$sql = <<<_SQL_
create table if not exists $table(
	date  date          not null,
	wday  char (3)      not null,
	type  varchar (20)  not null,
	value varchar (200) not null,
	count int           not null,
	primary key (date, type, value)
);
_SQL_;
		
		// SQLを返す
		return $sql;
		
	}
	
	//---------------------------------------------------------
	//  時間別 UU＆PV数テーブルを作成（access_yyyy_mm.db）
	//---------------------------------------------------------
	
	public static function createCountTable($table) {
		
		// クエリーを作成
		$sql = <<<_SQL_
create table if not exists $table(
	date   date     not null,
	wday   char (3) not null,
	sum_uu int default 0,
	sum_pv int default 0,
	h00_uu int default 0,
	h01_uu int default 0,
	h02_uu int default 0,
	h03_uu int default 0,
	h04_uu int default 0,
	h05_uu int default 0,
	h06_uu int default 0,
	h07_uu int default 0,
	h08_uu int default 0,
	h09_uu int default 0,
	h10_uu int default 0,
	h11_uu int default 0,
	h12_uu int default 0,
	h13_uu int default 0,
	h14_uu int default 0,
	h15_uu int default 0,
	h16_uu int default 0,
	h17_uu int default 0,
	h18_uu int default 0,
	h19_uu int default 0,
	h20_uu int default 0,
	h21_uu int default 0,
	h22_uu int default 0,
	h23_uu int default 0,
	h00_pv int default 0,
	h01_pv int default 0,
	h02_pv int default 0,
	h03_pv int default 0,
	h04_pv int default 0,
	h05_pv int default 0,
	h06_pv int default 0,
	h07_pv int default 0,
	h08_pv int default 0,
	h09_pv int default 0,
	h10_pv int default 0,
	h11_pv int default 0,
	h12_pv int default 0,
	h13_pv int default 0,
	h14_pv int default 0,
	h15_pv int default 0,
	h16_pv int default 0,
	h17_pv int default 0,
	h18_pv int default 0,
	h19_pv int default 0,
	h20_pv int default 0,
	h21_pv int default 0,
	h22_pv int default 0,
	h23_pv int default 0,
	primary key (date)
);
_SQL_;
		
		// SQLを返す
		return $sql;
		
	}
	
}

